A [Formative](https://github.com/johncronan/formative) plugin for reviewing
and scoring applicant submissions, **reviewpanel** allows a group of people to
evaluate the submissions on a Formative form. You can create cohorts and
presentation formats, set up panelist logins, define metrics, and
determine scores.
